@@ -6,8 +6,13 @@
 # 1. Checking if partition table correct (on boundary, bootable)
 # 2. cat mbr
 # 3. syslinux -fs
+#
+# Append PATH
+export PATH=/sbin:/usr/sbin:/bin:/usr/bin:$PATH
+
 #
 prog="$(basename $0)"
+path_of_prog="$(LC_ALL=C cd $(dirname $0)/../../ ; pwd)"
 
 #
 [ -z "$SETCOLOR_SUCCESS" ] && SETCOLOR_SUCCESS="echo -en \\033[1;32m"
@@ -77,6 +82,11 @@ if [ -z "$target_part" ]; then
   USAGE
   exit 1
 fi
+if ! type parted &>/dev/null; then
+  echo "Parted was not found on this GNU/Linux system. Please install it."
+  echo "Program terminated!"
+  exit 1
+fi
 
 # Make sure target_part is partition device name, not disk device name
 if [ -z "$(echo $target_part | grep -iE "/dev/[hsu][bd][a-z]+[[:digit:]]+")" ]; then
@@ -149,13 +159,14 @@ if [ -z "$(LANG=C parted -s $target_disk print | grep -E "^[[:space:]]*${pt_dev_
 fi
 
 # 1. Check if partition start/end on cylinder boundary
-if [ -n "$(LANG=C fdisk -l $target_disk | grep -iE "(not start on cylinder boundary|not end on cylinder boundary)")" ]; then
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
-  echo "Some partition does not start or end on cylinder boundary! This disk will not be able to boot via syslinux!" 
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-  echo "Program terminated!"
-  exit 1
-fi
+# //NOTE// This is not really required. Comment it on Sep/21/2010.
+#if [ -n "$(LANG=C fdisk -l $target_disk | grep -iE "(not start on cylinder boundary|not end on cylinder boundary)")" ]; then
+#  [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
+#  echo "Some partition does not start or end on cylinder boundary! This disk will not be able to boot via syslinux!" 
+#  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+#  echo "Program terminated!"
+#  exit 1
+#fi
 
 # 2. Bootable ?
 bootable="$(LANG=C fdisk -l $target_disk | grep -Ew "^$target_part" | awk -F" " '{print $2}')"
@@ -173,21 +184,21 @@ fi
 
 # 3. MBR
 to_continue_or_not "Do you want to install mbr on $target_disk $on_this_machine ?"
-echo "Running: cat ../mbr/mbr.bin > $target_disk"
-cat ../mbr/mbr.bin > $target_disk
+echo "Running: cat $path_of_prog/utils/mbr/mbr.bin > $target_disk"
+cat $path_of_prog/utils/mbr/mbr.bin > $target_disk
 
 echo "--------------------------------------------"
 # 4.
 to_continue_or_not "Do you want to install the SYSLINUX bootloader on $target_part $on_this_machine ?"
 # Since most of the cases when makeboot.sh is run, all the files are in FAT (USB flash drive normally uses FAT), we have to make syslinux executable.
 echo "We need a filesystem supporting Unix file mode for syslinux. Copying syslinux from FAT to /tmp/..."
-syslinux_tmpd="$(mktemp -d /tmp/syslinux.XXXXXX)"
-cp -fv syslinux $syslinux_tmpd
+syslinux_tmpd="$(mktemp -d /tmp/syslinux_tmp.XXXXXX)"
+cp -fv $path_of_prog/utils/linux/syslinux $syslinux_tmpd
 chmod u+x $syslinux_tmpd/syslinux
-echo "Running: $syslinux_tmpd/syslinux -f $target_part "
-$syslinux_tmpd/syslinux -f $target_part
+echo "Running: $syslinux_tmpd/syslinux -f -i $target_part "
+$syslinux_tmpd/syslinux -f -i $target_part
 echo "done!"
 [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
 echo "//NOTE// If your USB flash drive fails to boot (maybe buggy BIOS), try to use \"syslinux -fs $target_part\", i.e. running with \"-s\"."
 [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-[ -d "$syslinux_tmpd" -a -n "$syslinux_tmpd" ] && rm -rf $syslinux_tmpd
+[ -d "$syslinux_tmpd" -a -n "$(echo $syslinux_tmpd | grep "syslinux_tmp" )" ] && rm -rf $syslinux_tmpd
